@@ -23,7 +23,7 @@ gg_miss_case_cumsum <- function(x, breaks = 20){
     ggplot(aes(x = stats::reorder(case, n_miss_cumsum),
                y = n_miss_cumsum,
                group = 1)) +
-    geom_line(size = 2) +
+    geom_line(linewidth = 2) +
     labs(x = "Case",
          y = "Cumulative sum of missing values") +
     scale_x_discrete(breaks = seq(0,
