@@ -1,10 +1,8 @@
-context("add_any_miss")
-
 df <- data.frame(x = c(NA, 1:4),
              y = c(NA, NA, 1:3))
 
 test_that("add_any_miss returns a tibble",{
-  expect_is(add_any_miss(df,x), "tbl_df")
+  expect_s3_class(add_any_miss(df,x), "tbl_df")
 })
 
 test_that("add_any_miss respects dimensions",{
