@@ -1,8 +1,6 @@
-context("as_shadow")
-
 test_that("as_shadow returns a data.frame or tibble",{
-  expect_is(as_shadow(airquality), "data.frame")
-  expect_is(as_shadow(airquality), "tbl")
+  expect_s3_class(as_shadow(airquality), "data.frame")
+  expect_s3_class(as_shadow(airquality), "tbl")
 })
 
 test_df <- data.frame(x = c(1,2),
@@ -16,15 +14,15 @@ test_that("as_shadow returns correct values",{
 })
 
 test_that("as_shadow returns factors",{
-  expect_is(test_df$x_NA, "factor")
-  expect_is(test_df$y_NA, "factor")
-  expect_is(test_df$z_NA, "factor")
+  expect_s3_class(test_df$x_NA, "factor")
+  expect_s3_class(test_df$y_NA, "factor")
+  expect_s3_class(test_df$z_NA, "factor")
 })
 
 test_that("as_shadow returns shade",{
-  expect_is(test_df$x_NA, "shade")
-  expect_is(test_df$y_NA, "shade")
-  expect_is(test_df$z_NA, "shade")
+  expect_s3_class(test_df$x_NA, "shade")
+  expect_s3_class(test_df$y_NA, "shade")
+  expect_s3_class(test_df$z_NA, "shade")
 })
 
 test_that("as_shadow returns correct levels",{
