@@ -1,5 +1,3 @@
-context("impute_below_at works")
-
 miss_vec <- rnorm(100)
 
 # add 20 missing values
@@ -21,8 +19,6 @@ test_that("impute_below_at works with vars",{
   )
 })
 
-context("impute_below_if works")
-
 miss_vec <- rnorm(100)
 
 # add 20 missing values
