@@ -1,5 +1,3 @@
-context("unbind shadow")
-
 df <- data.frame(x = c(NA, 1:4),
                  y = c(NA, NA, 1:3))
 
@@ -7,7 +5,7 @@ nab <- nabular(df)
 nabu <- unbind_shadow(nab)
 
 test_that("unbind_shadow returns tibble", {
-  expect_is(nabu, c("tbl_df"))
+  expect_s3_class(nabu, c("tbl_df"))
 })
 
 test_that("unbind_shadow returns right dimensions", {
